require "oj"
require "rest-client"

module Chell
  class Client
    FORMATS = {
      json: "application/json",
      gzip: "application/x-gzip"
    }.freeze

    def initialize(options = {})
      @access_key = options.fetch(:access_key)
      @secret_key = options.fetch(:secret_key)
      @url = options.fetch(:url)
    end

    def courses
      parse_json(resource["/courses"].get.body)
    end

    def course(id)
      path = "/courses/#{id}"
      headers = { accept: FORMATS[:json] }

      response = resource[path].get(headers)
      parse_json(response.body)
    end

    def course_content(id, version_id)
      path = "/courses/#{id}/versions/#{version_id}"
      headers = { accept: FORMATS[:gzip] }

      resource[path].get(headers).body
    end

    private

    def parse_json(body)
      Oj.default_options = { mode: :compat, symbol_keys: true }
      Oj.load(body)
    end

    def resource
      @resource ||= RestClient::Resource.new(@url, user: @access_key, password: @secret_key)
    end
  end
end
